@@ -170,9 +170,9 @@ mod test {
     #[rustfmt::skip]
     fn test_dragon_grammar() {
         // From http://binarysculpting.com/2012/02/04/computing-lr1-closure/
-        let grm = &YaccGrammar::new(
+        let grm = YaccGrammar::new(
             YaccKind::Original(YaccOriginalActionKind::GenericParseTree),
-            &"
+            "
           %start S
           %%
           S: L '=' R | R;
@@ -200,7 +200,7 @@ mod test {
     fn eco_grammar() -> YaccGrammar {
         YaccGrammar::new(
             YaccKind::Original(YaccOriginalActionKind::GenericParseTree),
-            &"
+            "
           %start S
           %token a b c d f
           %%
@@ -251,7 +251,7 @@ mod test {
     fn grammar3() -> YaccGrammar {
         YaccGrammar::new(
             YaccKind::Original(YaccOriginalActionKind::GenericParseTree),
-            &"
+            "
           %start S
           %token a b c d
           %%
