@@ -426,7 +426,7 @@ mod test {
     fn grammar3() -> YaccGrammar {
         YaccGrammar::new(
             YaccKind::Original(YaccOriginalActionKind::GenericParseTree),
-            &"
+            "
           %start S
           %token a b c d
           %%
@@ -447,65 +447,65 @@ mod test {
         assert_eq!(sg.all_edges_len(), 10);
 
         assert_eq!(sg.closed_state(sg.start_state()).items.len(), 3);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "^", 0, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "S", 0, SIdx(0), vec!["$", "b"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "S", 1, SIdx(0), vec!["$", "b"]);
+        state_exists(&grm, sg.closed_state(sg.start_state()), "^", 0, SIdx(0), vec!["$"]);
+        state_exists(&grm, sg.closed_state(sg.start_state()), "S", 0, SIdx(0), vec!["$", "b"]);
+        state_exists(&grm, sg.closed_state(sg.start_state()), "S", 1, SIdx(0), vec!["$", "b"]);
 
         let s1 = sg.edge(sg.start_state(), Symbol::Rule(grm.rule_idx("S").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s1).items.len(), 2);
-        state_exists(&grm, &sg.closed_state(s1), "^", 0, SIdx(1), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(s1), "S", 0, SIdx(1), vec!["$", "b"]);
+        state_exists(&grm, sg.closed_state(s1), "^", 0, SIdx(1), vec!["$"]);
+        state_exists(&grm, sg.closed_state(s1), "S", 0, SIdx(1), vec!["$", "b"]);
 
         let s2 = sg.edge(s1, Symbol::Token(grm.token_idx("b").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s2).items.len(), 1);
-        state_exists(&grm, &sg.closed_state(s2), "S", 0, SIdx(2), vec!["$", "b"]);
+        state_exists(&grm, sg.closed_state(s2), "S", 0, SIdx(2), vec!["$", "b"]);
 
         let s3 = sg.edge(sg.start_state(), Symbol::Token(grm.token_idx("b").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s3).items.len(), 4);
-        state_exists(&grm, &sg.closed_state(s3), "S", 1, SIdx(1), vec!["$", "b", "c"]);
-        state_exists(&grm, &sg.closed_state(s3), "A", 0, SIdx(0), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s3), "A", 1, SIdx(0), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s3), "A", 2, SIdx(0), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s3), "S", 1, SIdx(1), vec!["$", "b", "c"]);
+        state_exists(&grm, sg.closed_state(s3), "A", 0, SIdx(0), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s3), "A", 1, SIdx(0), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s3), "A", 2, SIdx(0), vec!["a"]);
 
         let s4 = sg.edge(s3, Symbol::Rule(grm.rule_idx("A").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s4).items.len(), 1);
-        state_exists(&grm, &sg.closed_state(s4), "S", 1, SIdx(2), vec!["$", "b", "c"]);
+        state_exists(&grm, sg.closed_state(s4), "S", 1, SIdx(2), vec!["$", "b", "c"]);
 
         let s5 = sg.edge(s4, Symbol::Token(grm.token_idx("a").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s5).items.len(), 1);
-        state_exists(&grm, &sg.closed_state(s5), "S", 1, SIdx(3), vec!["$", "b", "c"]);
+        state_exists(&grm, sg.closed_state(s5), "S", 1, SIdx(3), vec!["$", "b", "c"]);
 
         let s6 = sg.edge(s3, Symbol::Token(grm.token_idx("a").unwrap())).unwrap();
         // result from merging 10 into 3
         assert_eq!(s3, sg.edge(s6, Symbol::Token(grm.token_idx("b").unwrap())).unwrap());
         assert_eq!(sg.closed_state(s6).items.len(), 5);
-        state_exists(&grm, &sg.closed_state(s6), "A", 0, SIdx(1), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s6), "A", 1, SIdx(1), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s6), "A", 2, SIdx(1), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s6), "S", 0, SIdx(0), vec!["b", "c"]);
-        state_exists(&grm, &sg.closed_state(s6), "S", 1, SIdx(0), vec!["b", "c"]);
+        state_exists(&grm, sg.closed_state(s6), "A", 0, SIdx(1), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s6), "A", 1, SIdx(1), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s6), "A", 2, SIdx(1), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s6), "S", 0, SIdx(0), vec!["b", "c"]);
+        state_exists(&grm, sg.closed_state(s6), "S", 1, SIdx(0), vec!["b", "c"]);
 
         let s7 = sg.edge(s6, Symbol::Rule(grm.rule_idx("S").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s7).items.len(), 3);
-        state_exists(&grm, &sg.closed_state(s7), "A", 0, SIdx(2), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s7), "A", 2, SIdx(2), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s7), "S", 0, SIdx(1), vec!["b", "c"]);
+        state_exists(&grm, sg.closed_state(s7), "A", 0, SIdx(2), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s7), "A", 2, SIdx(2), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s7), "S", 0, SIdx(1), vec!["b", "c"]);
 
         let s8 = sg.edge(s7, Symbol::Token(grm.token_idx("c").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s8).items.len(), 1);
-        state_exists(&grm, &sg.closed_state(s8), "A", 0, SIdx(3), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s8), "A", 0, SIdx(3), vec!["a"]);
 
         let s9 = sg.edge(s7, Symbol::Token(grm.token_idx("b").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s9).items.len(), 2);
-        state_exists(&grm, &sg.closed_state(s9), "A", 2, SIdx(3), vec!["a"]);
-        state_exists(&grm, &sg.closed_state(s9), "S", 0, SIdx(2), vec!["b", "c"]);
+        state_exists(&grm, sg.closed_state(s9), "A", 2, SIdx(3), vec!["a"]);
+        state_exists(&grm, sg.closed_state(s9), "S", 0, SIdx(2), vec!["b", "c"]);
     }
 
     // Pager grammar
     fn grammar_pager() -> YaccGrammar {
         YaccGrammar::new(
             YaccKind::Original(YaccOriginalActionKind::GenericParseTree),
-            &"
+            "
             %start X
             %%
              X : 'a' Y 'd' | 'a' Z 'c' | 'a' T | 'b' Y 'e' | 'b' Z 'd' | 'b' T;
@@ -521,136 +521,136 @@ mod test {
 
     #[rustfmt::skip]
     fn test_pager_graph(grm: &YaccGrammar) {
-        let sg = pager_stategraph(&grm);
+        let sg = pager_stategraph(grm);
 
         assert_eq!(sg.all_states_len(), StIdx(23));
         assert_eq!(sg.all_edges_len(), 27);
 
         // State 0
         assert_eq!(sg.closed_state(sg.start_state()).items.len(), 7);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "^", 0, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "X", 0, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "X", 1, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "X", 2, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "X", 3, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "X", 4, SIdx(0), vec!["$"]);
-        state_exists(&grm, &sg.closed_state(sg.start_state()), "X", 5, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "^", 0, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "X", 0, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "X", 1, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "X", 2, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "X", 3, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "X", 4, SIdx(0), vec!["$"]);
+        state_exists(grm, sg.closed_state(sg.start_state()), "X", 5, SIdx(0), vec!["$"]);
 
         let s1 = sg.edge(sg.start_state(), Symbol::Token(grm.token_idx("a").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s1).items.len(), 7);
-        state_exists(&grm, &sg.closed_state(s1), "X", 0, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s1), "X", 1, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s1), "X", 2, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s1), "Y", 0, SIdx(0), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s1), "Y", 1, SIdx(0), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s1), "Z", 0, SIdx(0), vec!["c"]);
-        state_exists(&grm, &sg.closed_state(s1), "T", 0, SIdx(0), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1), "X", 0, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1), "X", 1, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1), "X", 2, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1), "Y", 0, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s1), "Y", 1, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s1), "Z", 0, SIdx(0), vec!["c"]);
+        state_exists(grm, sg.closed_state(s1), "T", 0, SIdx(0), vec!["a", "d", "e", "$"]);
 
         let s7 = sg.edge(sg.start_state(), Symbol::Token(grm.token_idx("b").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s7).items.len(), 7);
-        state_exists(&grm, &sg.closed_state(s7), "X", 3, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s7), "X", 4, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s7), "X", 5, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s1), "Y", 0, SIdx(0), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s1), "Y", 1, SIdx(0), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s1), "Z", 0, SIdx(0), vec!["c"]);
-        state_exists(&grm, &sg.closed_state(s1), "T", 0, SIdx(0), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7), "X", 3, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7), "X", 4, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7), "X", 5, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1), "Y", 0, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s1), "Y", 1, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s1), "Z", 0, SIdx(0), vec!["c"]);
+        state_exists(grm, sg.closed_state(s1), "T", 0, SIdx(0), vec!["a", "d", "e", "$"]);
 
         let s4 = sg.edge(s1, Symbol::Token(grm.token_idx("u").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s4).items.len(), 8);
         assert_eq!(s4, sg.edge(s7, Symbol::Token(grm.token_idx("u").unwrap())).unwrap());
-        state_exists(&grm, &sg.closed_state(s4), "Y", 1, SIdx(1), vec!["d", "e"]);
-        state_exists(&grm, &sg.closed_state(s4), "T", 0, SIdx(1), vec!["a", "d", "e", "$"]);
-        state_exists(&grm, &sg.closed_state(s4), "X", 0, SIdx(0), vec!["a", "d", "e"]);
-        state_exists(&grm, &sg.closed_state(s4), "X", 1, SIdx(0), vec!["a", "d", "e"]);
-        state_exists(&grm, &sg.closed_state(s4), "X", 2, SIdx(0), vec!["a", "d", "e"]);
-        state_exists(&grm, &sg.closed_state(s4), "X", 3, SIdx(0), vec!["a", "d", "e"]);
-        state_exists(&grm, &sg.closed_state(s4), "X", 4, SIdx(0), vec!["a", "d", "e"]);
-        state_exists(&grm, &sg.closed_state(s4), "X", 5, SIdx(0), vec!["a", "d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "Y", 1, SIdx(1), vec!["d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "T", 0, SIdx(1), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s4), "X", 0, SIdx(0), vec!["a", "d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "X", 1, SIdx(0), vec!["a", "d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "X", 2, SIdx(0), vec!["a", "d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "X", 3, SIdx(0), vec!["a", "d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "X", 4, SIdx(0), vec!["a", "d", "e"]);
+        state_exists(grm, sg.closed_state(s4), "X", 5, SIdx(0), vec!["a", "d", "e"]);
 
         assert_eq!(s1, sg.edge(s4, Symbol::Token(grm.token_idx("a").unwrap())).unwrap());
         assert_eq!(s7, sg.edge(s4, Symbol::Token(grm.token_idx("b").unwrap())).unwrap());
 
         let s2 = sg.edge(s1, Symbol::Token(grm.token_idx("t").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s2).items.len(), 3);
-        state_exists(&grm, &sg.closed_state(s2), "Y", 0, SIdx(1), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s2), "Z", 0, SIdx(1), vec!["c"]);
-        state_exists(&grm, &sg.closed_state(s2), "W", 0, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s2), "Y", 0, SIdx(1), vec!["d"]);
+        state_exists(grm, sg.closed_state(s2), "Z", 0, SIdx(1), vec!["c"]);
+        state_exists(grm, sg.closed_state(s2), "W", 0, SIdx(0), vec!["d"]);
 
         let s3 = sg.edge(s2, Symbol::Token(grm.token_idx("u").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s3).items.len(), 3);
-        state_exists(&grm, &sg.closed_state(s3), "Z", 0, SIdx(2), vec!["c"]);
-        state_exists(&grm, &sg.closed_state(s3), "W", 0, SIdx(1), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s3), "V", 0, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s3), "Z", 0, SIdx(2), vec!["c"]);
+        state_exists(grm, sg.closed_state(s3), "W", 0, SIdx(1), vec!["d"]);
+        state_exists(grm, sg.closed_state(s3), "V", 0, SIdx(0), vec!["d"]);
 
         let s5 = sg.edge(s4, Symbol::Rule(grm.rule_idx("X").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s5).items.len(), 2);
-        state_exists(&grm, &sg.closed_state(s5), "Y", 1, SIdx(2), vec!["d", "e"]);
-        state_exists(&grm, &sg.closed_state(s5), "T", 0, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s5), "Y", 1, SIdx(2), vec!["d", "e"]);
+        state_exists(grm, sg.closed_state(s5), "T", 0, SIdx(2), vec!["a", "d", "e", "$"]);
 
         let s6 = sg.edge(s5, Symbol::Token(grm.token_idx("a").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s6).items.len(), 1);
-        state_exists(&grm, &sg.closed_state(s6), "T", 0, SIdx(3), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s6), "T", 0, SIdx(3), vec!["a", "d", "e", "$"]);
 
         let s8 = sg.edge(s7, Symbol::Token(grm.token_idx("t").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s8).items.len(), 3);
-        state_exists(&grm, &sg.closed_state(s8), "Y", 0, SIdx(1), vec!["e"]);
-        state_exists(&grm, &sg.closed_state(s8), "Z", 0, SIdx(1), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s8), "W", 0, SIdx(0), vec!["e"]);
+        state_exists(grm, sg.closed_state(s8), "Y", 0, SIdx(1), vec!["e"]);
+        state_exists(grm, sg.closed_state(s8), "Z", 0, SIdx(1), vec!["d"]);
+        state_exists(grm, sg.closed_state(s8), "W", 0, SIdx(0), vec!["e"]);
 
         let s9 = sg.edge(s8, Symbol::Token(grm.token_idx("u").unwrap())).unwrap();
         assert_eq!(sg.closed_state(s9).items.len(), 3);
-        state_exists(&grm, &sg.closed_state(s9), "Z", 0, SIdx(2), vec!["d"]);
-        state_exists(&grm, &sg.closed_state(s9), "W", 0, SIdx(1), vec!["e"]);
-        state_exists(&grm, &sg.closed_state(s3), "V", 0, SIdx(0), vec!["d"]);
+        state_exists(grm, sg.closed_state(s9), "Z", 0, SIdx(2), vec!["d"]);
+        state_exists(grm, sg.closed_state(s9), "W", 0, SIdx(1), vec!["e"]);
+        state_exists(grm, sg.closed_state(s3), "V", 0, SIdx(0), vec!["d"]);
 
         // Ommitted successors from the graph in Fig.3
 
         // X-successor of S0
         let s0x = sg.edge(sg.start_state(), Symbol::Rule(grm.rule_idx("X").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s0x), "^", 0, SIdx(1), vec!["$"]);
+        state_exists(grm, sg.closed_state(s0x), "^", 0, SIdx(1), vec!["$"]);
 
         // Y-successor of S1 (and it's d-successor)
         let s1y = sg.edge(s1, Symbol::Rule(grm.rule_idx("Y").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s1y), "X", 0, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1y), "X", 0, SIdx(2), vec!["a", "d", "e", "$"]);
         let s1yd = sg.edge(s1y, Symbol::Token(grm.token_idx("d").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s1yd), "X", 0, SIdx(3), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1yd), "X", 0, SIdx(3), vec!["a", "d", "e", "$"]);
 
         // Z-successor of S1 (and it's successor)
         let s1z = sg.edge(s1, Symbol::Rule(grm.rule_idx("Z").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s1z), "X", 1, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1z), "X", 1, SIdx(2), vec!["a", "d", "e", "$"]);
         let s1zc = sg.edge(s1z, Symbol::Token(grm.token_idx("c").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s1zc), "X", 1, SIdx(3), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1zc), "X", 1, SIdx(3), vec!["a", "d", "e", "$"]);
 
         // T-successor of S1
         let s1t = sg.edge(s1, Symbol::Rule(grm.rule_idx("T").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s1t), "X", 2, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s1t), "X", 2, SIdx(2), vec!["a", "d", "e", "$"]);
 
         // Y-successor of S7 (and it's d-successor)
         let s7y = sg.edge(s7, Symbol::Rule(grm.rule_idx("Y").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s7y), "X", 3, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7y), "X", 3, SIdx(2), vec!["a", "d", "e", "$"]);
         let s7ye = sg.edge(s7y, Symbol::Token(grm.token_idx("e").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s7ye), "X", 3, SIdx(3), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7ye), "X", 3, SIdx(3), vec!["a", "d", "e", "$"]);
 
         // Z-successor of S7 (and it's successor)
         let s7z = sg.edge(s7, Symbol::Rule(grm.rule_idx("Z").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s7z), "X", 4, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7z), "X", 4, SIdx(2), vec!["a", "d", "e", "$"]);
         let s7zd = sg.edge(s7z, Symbol::Token(grm.token_idx("d").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s7zd), "X", 4, SIdx(3), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7zd), "X", 4, SIdx(3), vec!["a", "d", "e", "$"]);
 
         // T-successor of S7
         let s7t = sg.edge(s7, Symbol::Rule(grm.rule_idx("T").unwrap())).unwrap();
-        state_exists(&grm, &sg.closed_state(s7t), "X", 5, SIdx(2), vec!["a", "d", "e", "$"]);
+        state_exists(grm, sg.closed_state(s7t), "X", 5, SIdx(2), vec!["a", "d", "e", "$"]);
 
         // W-successor of S2 and S8 (merged)
         let s8w = sg.edge(s8, Symbol::Rule(grm.rule_idx("W").unwrap())).unwrap();
         assert_eq!(s8w, sg.edge(s2, Symbol::Rule(grm.rule_idx("W").unwrap())).unwrap());
-        state_exists(&grm, &sg.closed_state(s8w), "Y", 0, SIdx(2), vec!["d", "e"]);
+        state_exists(grm, sg.closed_state(s8w), "Y", 0, SIdx(2), vec!["d", "e"]);
 
         // V-successor of S3 and S9 (merged)
         let s9v = sg.edge(s9, Symbol::Rule(grm.rule_idx("V").unwrap())).unwrap();
         assert_eq!(s9v, sg.edge(s3, Symbol::Rule(grm.rule_idx("V").unwrap())).unwrap());
-        state_exists(&grm, &sg.closed_state(s9v), "W", 0, SIdx(2), vec!["d", "e"]);
+        state_exists(grm, sg.closed_state(s9v), "W", 0, SIdx(2), vec!["d", "e"]);
     }
 
     #[test]
@@ -677,6 +677,6 @@ mod test {
 
         // State 0
         assert_eq!(sg.core_state(sg.start_state()).items.len(), 1);
-        state_exists(&grm, &sg.core_state(sg.start_state()), "^", 0, SIdx(0), vec!["$"]);
+        state_exists(&grm, sg.core_state(sg.start_state()), "^", 0, SIdx(0), vec!["$"]);
     }
 }
